# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_qms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_qms.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17steammessages_qms.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"2\n\x0fGameSearchParam\x12\x10\n\x08key_name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\"\xe9\x01\n(CQueuedMatchmaking_SearchForGame_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x12\n\nplayer_min\x18\x04 \x01(\r\x12\x12\n\nplayer_max\x18\x05 \x01(\r\x12\x14\n\x0csteamidlobby\x18\x06 \x01(\x06\x12\x10\n\x08searchid\x18\x07 \x01(\x04\"\x87\x03\n)CQueuedMatchmaking_SearchForGame_Response\x12I\n\x10gamesearchresult\x18\x01 \x01(\x0e\x32\x12.EGameSearchResult:\x1bk_EGameSearchResult_Invalid\x12\x10\n\x08searchid\x18\x02 \x01(\x04\x12\x1d\n\x15seconds_time_estimate\x18\x03 \x01(\r\x12\x16\n\x0epoll_frequency\x18\x04 \x01(\r\x12\x17\n\x0f\x63ount_searching\x18\x05 \x01(\r\x12\x18\n\x10players_in_match\x18\x06 \x01(\r\x12\x18\n\x10players_accepted\x18\x07 \x01(\r\x12\x16\n\x0e\x63onnect_string\x18\t \x01(\t\x12\x13\n\x0bsteamidhost\x18\n \x01(\x06\x12\x18\n\x10rtime_match_made\x18\x0b \x01(\r\x12\x11\n\trtime_now\x18\x0c \x01(\r\x12\x1f\n\x17steamid_canceled_search\x18\r \x01(\x06\"\x97\x02\n3CQueuedMatchmakingGameHost_SearchForPlayers_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x12\n\nplayer_min\x18\x04 \x01(\r\x12\x12\n\nplayer_max\x18\x05 \x01(\r\x12\x1c\n\x14player_max_team_size\x18\x06 \x01(\r\x12\x19\n\x11\x63onnection_string\x18\x07 \x01(\t\x12\x10\n\x08searchid\x18\x08 \x01(\x04\"\x93\x01\n\x0bPlayerFound\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x12.EGameSearchAction:\x18k_EGameSearchAction_None\x12 \n\x06params\x18\x03 \x03(\x0b\x32\x10.GameSearchParam\x12\x13\n\x0bteam_number\x18\x04 \x01(\r\"\x88\x02\n4CQueuedMatchmakingGameHost_SearchForPlayers_Response\x12I\n\x10gamesearchresult\x18\x01 \x01(\x0e\x32\x12.EGameSearchResult:\x1bk_EGameSearchResult_Invalid\x12\x10\n\x08searchid\x18\x02 \x01(\x04\x12\x16\n\x0epoll_frequency\x18\x03 \x01(\r\x12\x0f\n\x07matchid\x18\x04 \x01(\x04\x12\x1d\n\x07players\x18\x05 \x03(\x0b\x32\x0c.PlayerFound\x12\x18\n\x10rtime_match_made\x18\x06 \x01(\r\x12\x11\n\trtime_now\x18\x07 \x01(\r\".\n\x0cPlayerResult\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05value\x18\x02 \x01(\r\"~\n5CQueuedMatchmakingGameHost_SubmitPlayerResult_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\x12%\n\x0eplayer_results\x18\x03 \x03(\x0b\x32\r.PlayerResult\"8\n6CQueuedMatchmakingGameHost_SubmitPlayerResult_Response\"L\n*CQueuedMatchmakingGameHost_EndGame_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\"-\n+CQueuedMatchmakingGameHost_EndGame_Response*\x92\x01\n\x11\x45GameSearchAction\x12\x1c\n\x18k_EGameSearchAction_None\x10\x00\x12\x1e\n\x1ak_EGameSearchAction_Accept\x10\x01\x12\x1f\n\x1bk_EGameSearchAction_Decline\x10\x02\x12\x1e\n\x1ak_EGameSearchAction_Cancel\x10\x03*\xbc\x02\n\x11\x45GameSearchResult\x12\x1f\n\x1bk_EGameSearchResult_Invalid\x10\x00\x12(\n$k_EGameSearchResult_SearchInProgress\x10\x01\x12+\n\'k_EGameSearchResult_SearchFailedNoHosts\x10\x02\x12\'\n#k_EGameSearchResult_SearchGameFound\x10\x03\x12.\n*k_EGameSearchResult_SearchCompleteAccepted\x10\x04\x12.\n*k_EGameSearchResult_SearchCompleteDeclined\x10\x05\x12&\n\"k_EGameSearchResult_SearchCanceled\x10\x06\x32\xb2\x01\n\x11QueuedMatchmaking\x12}\n\rSearchForGame\x12).CQueuedMatchmaking_SearchForGame_Request\x1a*.CQueuedMatchmaking_SearchForGame_Response\"\x15\x82\xb5\x18\x11Search for a game\x1a\x1e\x82\xb5\x18\x1aQueued matchmaking service2\xeb\x03\n\x19QueuedMatchmakingGameHost\x12\x95\x01\n\x10SearchForPlayers\x12\x34.CQueuedMatchmakingGameHost_SearchForPlayers_Request\x1a\x35.CQueuedMatchmakingGameHost_SearchForPlayers_Response\"\x14\x82\xb5\x18\x10SearchForPlayers\x12\x9d\x01\n\x12SubmitPlayerResult\x12\x36.CQueuedMatchmakingGameHost_SubmitPlayerResult_Request\x1a\x37.CQueuedMatchmakingGameHost_SubmitPlayerResult_Response\"\x16\x82\xb5\x18\x12SubmitPlayerResult\x12q\n\x07\x45ndGame\x12+.CQueuedMatchmakingGameHost_EndGame_Request\x1a,.CQueuedMatchmakingGameHost_EndGame_Response\"\x0b\x82\xb5\x18\x07\x45ndGame\x1a#\x82\xb5\x18\x1fQueued matchmaking host serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EGAMESEARCHACTION = _descriptor.EnumDescriptor(
  name='EGameSearchAction',
  full_name='EGameSearchAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_Accept', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_Decline', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchAction_Cancel', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1828,
  serialized_end=1974,
)
_sym_db.RegisterEnumDescriptor(_EGAMESEARCHACTION)

EGameSearchAction = enum_type_wrapper.EnumTypeWrapper(_EGAMESEARCHACTION)
_EGAMESEARCHRESULT = _descriptor.EnumDescriptor(
  name='EGameSearchResult',
  full_name='EGameSearchResult',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchInProgress', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchFailedNoHosts', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchGameFound', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchCompleteAccepted', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchCompleteDeclined', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGameSearchResult_SearchCanceled', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1977,
  serialized_end=2293,
)
_sym_db.RegisterEnumDescriptor(_EGAMESEARCHRESULT)

EGameSearchResult = enum_type_wrapper.EnumTypeWrapper(_EGAMESEARCHRESULT)
k_EGameSearchAction_None = 0
k_EGameSearchAction_Accept = 1
k_EGameSearchAction_Decline = 2
k_EGameSearchAction_Cancel = 3
k_EGameSearchResult_Invalid = 0
k_EGameSearchResult_SearchInProgress = 1
k_EGameSearchResult_SearchFailedNoHosts = 2
k_EGameSearchResult_SearchGameFound = 3
k_EGameSearchResult_SearchCompleteAccepted = 4
k_EGameSearchResult_SearchCompleteDeclined = 5
k_EGameSearchResult_SearchCanceled = 6



_GAMESEARCHPARAM = _descriptor.Descriptor(
  name='GameSearchParam',
  full_name='GameSearchParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_name', full_name='GameSearchParam.key_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='GameSearchParam.value', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=137,
)


_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmaking_SearchForGame_Request',
  full_name='CQueuedMatchmaking_SearchForGame_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmaking_SearchForGame_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='CQueuedMatchmaking_SearchForGame_Request.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='CQueuedMatchmaking_SearchForGame_Request.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_min', full_name='CQueuedMatchmaking_SearchForGame_Request.player_min', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_max', full_name='CQueuedMatchmaking_SearchForGame_Request.player_max', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamidlobby', full_name='CQueuedMatchmaking_SearchForGame_Request.steamidlobby', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmaking_SearchForGame_Request.searchid', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=373,
)


_CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmaking_SearchForGame_Response',
  full_name='CQueuedMatchmaking_SearchForGame_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gamesearchresult', full_name='CQueuedMatchmaking_SearchForGame_Response.gamesearchresult', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmaking_SearchForGame_Response.searchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_time_estimate', full_name='CQueuedMatchmaking_SearchForGame_Response.seconds_time_estimate', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poll_frequency', full_name='CQueuedMatchmaking_SearchForGame_Response.poll_frequency', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_searching', full_name='CQueuedMatchmaking_SearchForGame_Response.count_searching', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players_in_match', full_name='CQueuedMatchmaking_SearchForGame_Response.players_in_match', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players_accepted', full_name='CQueuedMatchmaking_SearchForGame_Response.players_accepted', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CQueuedMatchmaking_SearchForGame_Response.connect_string', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamidhost', full_name='CQueuedMatchmaking_SearchForGame_Response.steamidhost', index=8,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_match_made', full_name='CQueuedMatchmaking_SearchForGame_Response.rtime_match_made', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_now', full_name='CQueuedMatchmaking_SearchForGame_Response.rtime_now', index=10,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_canceled_search', full_name='CQueuedMatchmaking_SearchForGame_Response.steamid_canceled_search', index=11,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=767,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SearchForPlayers_Request',
  full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_min', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.player_min', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_max', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.player_max', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_max_team_size', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.player_max_team_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_string', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.connection_string', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Request.searchid', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=1049,
)


_PLAYERFOUND = _descriptor.Descriptor(
  name='PlayerFound',
  full_name='PlayerFound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='PlayerFound.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='PlayerFound.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='PlayerFound.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team_number', full_name='PlayerFound.team_number', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1199,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SearchForPlayers_Response',
  full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gamesearchresult', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.gamesearchresult', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.searchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poll_frequency', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.poll_frequency', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.matchid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.players', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_match_made', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.rtime_match_made', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_now', full_name='CQueuedMatchmakingGameHost_SearchForPlayers_Response.rtime_now', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1466,
)


_PLAYERRESULT = _descriptor.Descriptor(
  name='PlayerResult',
  full_name='PlayerResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='PlayerResult.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PlayerResult.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1468,
  serialized_end=1514,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request',
  full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request.matchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='player_results', full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Request.player_results', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1516,
  serialized_end=1642,
)


_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Response',
  full_name='CQueuedMatchmakingGameHost_SubmitPlayerResult_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1700,
)


_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_EndGame_Request',
  full_name='CQueuedMatchmakingGameHost_EndGame_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CQueuedMatchmakingGameHost_EndGame_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CQueuedMatchmakingGameHost_EndGame_Request.matchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1778,
)


_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE = _descriptor.Descriptor(
  name='CQueuedMatchmakingGameHost_EndGame_Response',
  full_name='CQueuedMatchmakingGameHost_EndGame_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1780,
  serialized_end=1825,
)

_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST.fields_by_name['action'].enum_type = _EGAMESEARCHACTION
_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST.fields_by_name['params'].message_type = _GAMESEARCHPARAM
_CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE.fields_by_name['gamesearchresult'].enum_type = _EGAMESEARCHRESULT
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST.fields_by_name['action'].enum_type = _EGAMESEARCHACTION
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST.fields_by_name['params'].message_type = _GAMESEARCHPARAM
_PLAYERFOUND.fields_by_name['action'].enum_type = _EGAMESEARCHACTION
_PLAYERFOUND.fields_by_name['params'].message_type = _GAMESEARCHPARAM
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE.fields_by_name['gamesearchresult'].enum_type = _EGAMESEARCHRESULT
_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE.fields_by_name['players'].message_type = _PLAYERFOUND
_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST.fields_by_name['player_results'].message_type = _PLAYERRESULT
DESCRIPTOR.message_types_by_name['GameSearchParam'] = _GAMESEARCHPARAM
DESCRIPTOR.message_types_by_name['CQueuedMatchmaking_SearchForGame_Request'] = _CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST
DESCRIPTOR.message_types_by_name['CQueuedMatchmaking_SearchForGame_Response'] = _CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SearchForPlayers_Request'] = _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST
DESCRIPTOR.message_types_by_name['PlayerFound'] = _PLAYERFOUND
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SearchForPlayers_Response'] = _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE
DESCRIPTOR.message_types_by_name['PlayerResult'] = _PLAYERRESULT
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SubmitPlayerResult_Request'] = _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_SubmitPlayerResult_Response'] = _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_EndGame_Request'] = _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST
DESCRIPTOR.message_types_by_name['CQueuedMatchmakingGameHost_EndGame_Response'] = _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE
DESCRIPTOR.enum_types_by_name['EGameSearchAction'] = _EGAMESEARCHACTION
DESCRIPTOR.enum_types_by_name['EGameSearchResult'] = _EGAMESEARCHRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GameSearchParam = _reflection.GeneratedProtocolMessageType('GameSearchParam', (_message.Message,), {
  'DESCRIPTOR' : _GAMESEARCHPARAM,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:GameSearchParam)
  })
_sym_db.RegisterMessage(GameSearchParam)

CQueuedMatchmaking_SearchForGame_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmaking_SearchForGame_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmaking_SearchForGame_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmaking_SearchForGame_Request)

CQueuedMatchmaking_SearchForGame_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmaking_SearchForGame_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmaking_SearchForGame_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmaking_SearchForGame_Response)

CQueuedMatchmakingGameHost_SearchForPlayers_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SearchForPlayers_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SearchForPlayers_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SearchForPlayers_Request)

PlayerFound = _reflection.GeneratedProtocolMessageType('PlayerFound', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERFOUND,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:PlayerFound)
  })
_sym_db.RegisterMessage(PlayerFound)

CQueuedMatchmakingGameHost_SearchForPlayers_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SearchForPlayers_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SearchForPlayers_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SearchForPlayers_Response)

PlayerResult = _reflection.GeneratedProtocolMessageType('PlayerResult', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRESULT,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:PlayerResult)
  })
_sym_db.RegisterMessage(PlayerResult)

CQueuedMatchmakingGameHost_SubmitPlayerResult_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SubmitPlayerResult_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SubmitPlayerResult_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SubmitPlayerResult_Request)

CQueuedMatchmakingGameHost_SubmitPlayerResult_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_SubmitPlayerResult_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_SubmitPlayerResult_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_SubmitPlayerResult_Response)

CQueuedMatchmakingGameHost_EndGame_Request = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_EndGame_Request', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_EndGame_Request)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_EndGame_Request)

CQueuedMatchmakingGameHost_EndGame_Response = _reflection.GeneratedProtocolMessageType('CQueuedMatchmakingGameHost_EndGame_Response', (_message.Message,), {
  'DESCRIPTOR' : _CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE,
  '__module__' : 'steammessages_qms_pb2'
  # @@protoc_insertion_point(class_scope:CQueuedMatchmakingGameHost_EndGame_Response)
  })
_sym_db.RegisterMessage(CQueuedMatchmakingGameHost_EndGame_Response)


DESCRIPTOR._options = None

_QUEUEDMATCHMAKING = _descriptor.ServiceDescriptor(
  name='QueuedMatchmaking',
  full_name='QueuedMatchmaking',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\032Queued matchmaking service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2296,
  serialized_end=2474,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchForGame',
    full_name='QueuedMatchmaking.SearchForGame',
    index=0,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKING_SEARCHFORGAME_REQUEST,
    output_type=_CQUEUEDMATCHMAKING_SEARCHFORGAME_RESPONSE,
    serialized_options=b'\202\265\030\021Search for a game',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUEUEDMATCHMAKING)

DESCRIPTOR.services_by_name['QueuedMatchmaking'] = _QUEUEDMATCHMAKING


_QUEUEDMATCHMAKINGGAMEHOST = _descriptor.ServiceDescriptor(
  name='QueuedMatchmakingGameHost',
  full_name='QueuedMatchmakingGameHost',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030\037Queued matchmaking host service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2477,
  serialized_end=2968,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchForPlayers',
    full_name='QueuedMatchmakingGameHost.SearchForPlayers',
    index=0,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_REQUEST,
    output_type=_CQUEUEDMATCHMAKINGGAMEHOST_SEARCHFORPLAYERS_RESPONSE,
    serialized_options=b'\202\265\030\020SearchForPlayers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitPlayerResult',
    full_name='QueuedMatchmakingGameHost.SubmitPlayerResult',
    index=1,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_REQUEST,
    output_type=_CQUEUEDMATCHMAKINGGAMEHOST_SUBMITPLAYERRESULT_RESPONSE,
    serialized_options=b'\202\265\030\022SubmitPlayerResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndGame',
    full_name='QueuedMatchmakingGameHost.EndGame',
    index=2,
    containing_service=None,
    input_type=_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_REQUEST,
    output_type=_CQUEUEDMATCHMAKINGGAMEHOST_ENDGAME_RESPONSE,
    serialized_options=b'\202\265\030\007EndGame',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUEUEDMATCHMAKINGGAMEHOST)

DESCRIPTOR.services_by_name['QueuedMatchmakingGameHost'] = _QUEUEDMATCHMAKINGGAMEHOST

QueuedMatchmaking = service_reflection.GeneratedServiceType('QueuedMatchmaking', (_service.Service,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKING,
  __module__ = 'steammessages_qms_pb2'
  ))

QueuedMatchmaking_Stub = service_reflection.GeneratedServiceStubType('QueuedMatchmaking_Stub', (QueuedMatchmaking,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKING,
  __module__ = 'steammessages_qms_pb2'
  ))


QueuedMatchmakingGameHost = service_reflection.GeneratedServiceType('QueuedMatchmakingGameHost', (_service.Service,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKINGGAMEHOST,
  __module__ = 'steammessages_qms_pb2'
  ))

QueuedMatchmakingGameHost_Stub = service_reflection.GeneratedServiceStubType('QueuedMatchmakingGameHost_Stub', (QueuedMatchmakingGameHost,), dict(
  DESCRIPTOR = _QUEUEDMATCHMAKINGGAMEHOST,
  __module__ = 'steammessages_qms_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gameservers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_gameservers.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fsteammessages_gameservers.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x9f\x01\n\"CGameServers_GetServerList_Request\x12(\n\x06\x66ilter\x18\x01 \x01(\tB\x18\x82\xb5\x18\x14Query filter string.\x12O\n\x05limit\x18\x02 \x01(\r:\x03\x31\x30\x30\x42;\x82\xb5\x18\x37The maximum number of servers to return in the response\"\xe0\x03\n#CGameServers_GetServerList_Response\x12\x65\n\x07servers\x18\x01 \x03(\x0b\x32+.CGameServers_GetServerList_Response.ServerB\'\x82\xb5\x18#List of servers matching the filter\x1a\xd1\x02\n\x06Server\x12\x30\n\x04\x61\x64\x64r\x18\x01 \x01(\tB\"\x82\xb5\x18\x1eThe server\'s IP and query port\x12\x10\n\x08gameport\x18\x02 \x01(\r\x12\x10\n\x08specport\x18\x03 \x01(\r\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\r\n\x05\x61ppid\x18\x06 \x01(\r\x12\x0f\n\x07gamedir\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x0f\n\x07product\x18\t \x01(\t\x12\x0e\n\x06region\x18\n \x01(\x05\x12\x0f\n\x07players\x18\x0b \x01(\x05\x12\x13\n\x0bmax_players\x18\x0c \x01(\x05\x12\x0c\n\x04\x62ots\x18\r \x01(\x05\x12\x0b\n\x03map\x18\x0e \x01(\t\x12\x0e\n\x06secure\x18\x0f \x01(\x08\x12\x11\n\tdedicated\x18\x10 \x01(\x08\x12\n\n\x02os\x18\x11 \x01(\t\x12\x10\n\x08gametype\x18\x12 \x01(\t\"@\n*CGameServers_GetServerSteamIDsByIP_Request\x12\x12\n\nserver_ips\x18\x01 \x03(\t\"\x90\x01\n%CGameServers_IPsWithSteamIDs_Response\x12>\n\x07servers\x18\x01 \x03(\x0b\x32-.CGameServers_IPsWithSteamIDs_Response.Server\x1a\'\n\x06Server\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"E\n*CGameServers_GetServerIPsBySteamID_Request\x12\x17\n\x0fserver_steamids\x18\x01 \x03(\x06\"\x97\x03\n\"CGameServers_QueryByFakeIP_Request\x12/\n\x07\x66\x61ke_ip\x18\x01 \x01(\rB\x1e\x82\xb5\x18\x1a\x46\x61keIP of server to query.\x12\x34\n\tfake_port\x18\x02 \x01(\rB!\x82\xb5\x18\x1d\x46\x61ke port of server to query.\x12I\n\x06\x61pp_id\x18\x03 \x01(\rB9\x82\xb5\x18\x35\x41ppID to use.  Each AppID has its own FakeIP address.\x12j\n\nquery_type\x18\x04 \x01(\x0e\x32..CGameServers_QueryByFakeIP_Request.EQueryType:\rQuery_InvalidB\x17\x82\xb5\x18\x13What type of query?\"S\n\nEQueryType\x12\x11\n\rQuery_Invalid\x10\x00\x12\x0e\n\nQuery_Ping\x10\x01\x12\x11\n\rQuery_Players\x10\x02\x12\x0f\n\x0bQuery_Rules\x10\x03\"\xd0\x03\n\x1b\x43MsgGameServerPingQueryData\x12!\n\tserver_ip\x18\x01 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x12\n\nquery_port\x18\x02 \x01(\r\x12\x11\n\tgame_port\x18\x03 \x01(\r\x12\x16\n\x0espectator_port\x18\x04 \x01(\r\x12\x1d\n\x15spectator_server_name\x18\x05 \x01(\t\x12\x13\n\x0bserver_name\x18\x06 \x01(\t\x12\x0f\n\x07steamid\x18\x07 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x08 \x01(\r\x12\x0f\n\x07gamedir\x18\t \x01(\t\x12\x0b\n\x03map\x18\n \x01(\t\x12\x18\n\x10game_description\x18\x0b \x01(\t\x12\x10\n\x08gametype\x18\x0c \x01(\t\x12\x13\n\x0bnum_players\x18\r \x01(\r\x12\x13\n\x0bmax_players\x18\x0e \x01(\r\x12\x10\n\x08num_bots\x18\x0f \x01(\r\x12\x10\n\x08password\x18\x10 \x01(\x08\x12\x0e\n\x06secure\x18\x11 \x01(\x08\x12\x11\n\tdedicated\x18\x12 \x01(\x08\x12\x0f\n\x07version\x18\x13 \x01(\t\x12\x11\n\tsdr_popid\x18\x14 \x01(\x07\x12\x1b\n\x13sdr_location_string\x18\x15 \x01(\t\"\x95\x01\n\x1e\x43MsgGameServerPlayersQueryData\x12\x37\n\x07players\x18\x01 \x03(\x0b\x32&.CMsgGameServerPlayersQueryData.Player\x1a:\n\x06Player\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\r\x12\x13\n\x0btime_played\x18\x03 \x01(\r\"v\n\x1c\x43MsgGameServerRulesQueryData\x12\x31\n\x05rules\x18\x01 \x03(\x0b\x32\".CMsgGameServerRulesQueryData.Rule\x1a#\n\x04Rule\x12\x0c\n\x04rule\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xc2\x01\n%CGameServers_GameServerQuery_Response\x12/\n\tping_data\x18\x01 \x01(\x0b\x32\x1c.CMsgGameServerPingQueryData\x12\x35\n\x0cplayers_data\x18\x02 \x01(\x0b\x32\x1f.CMsgGameServerPlayersQueryData\x12\x31\n\nrules_data\x18\x03 \x01(\x0b\x32\x1d.CMsgGameServerRulesQueryData\"*\n(GameServerClient_QueryServerData_Request\"\xc6\x01\n)GameServerClient_QueryServerData_Response\x12/\n\tping_data\x18\x01 \x01(\x0b\x32\x1c.CMsgGameServerPingQueryData\x12\x35\n\x0cplayers_data\x18\x02 \x01(\x0b\x32\x1f.CMsgGameServerPlayersQueryData\x12\x31\n\nrules_data\x18\x03 \x01(\x0b\x32\x1d.CMsgGameServerRulesQueryData2\xbe\x05\n\x0bGameServers\x12\x8c\x01\n\rGetServerList\x12#.CGameServers_GetServerList_Request\x1a$.CGameServers_GetServerList_Response\"0\x82\xb5\x18,Gets a list of servers given a filter string\x12\xa4\x01\n\x15GetServerSteamIDsByIP\x12+.CGameServers_GetServerSteamIDsByIP_Request\x1a&.CGameServers_IPsWithSteamIDs_Response\"6\x82\xb5\x18\x32Gets a list of server SteamIDs given a list of IPs\x12\xad\x01\n\x15GetServerIPsBySteamID\x12+.CGameServers_GetServerIPsBySteamID_Request\x1a&.CGameServers_IPsWithSteamIDs_Response\"?\x82\xb5\x18;Gets a list of server IP addresses given a list of SteamIDs\x12\x90\x01\n\rQueryByFakeIP\x12#.CGameServers_QueryByFakeIP_Request\x1a&.CGameServers_GameServerQuery_Response\"2\x82\xb5\x18.Perform a query on a specific server by FakeIP\x1a\x36\x82\xb5\x18\x32\x41 service for searching and managing game servers.2\xe9\x01\n\x10GameServerClient\x12\x97\x01\n\x0fQueryServerData\x12).GameServerClient_QueryServerData_Request\x1a*.GameServerClient_QueryServerData_Response\"-\x82\xb5\x18)Steam is asking a gameserver for its data\x1a;\x82\xb5\x18\x33Service methods exposed by GameServer Steam clients\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])



_CGAMESERVERS_QUERYBYFAKEIP_REQUEST_EQUERYTYPE = _descriptor.EnumDescriptor(
  name='EQueryType',
  full_name='CGameServers_QueryByFakeIP_Request.EQueryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Query_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Query_Ping', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Query_Players', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Query_Rules', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1349,
  serialized_end=1432,
)
_sym_db.RegisterEnumDescriptor(_CGAMESERVERS_QUERYBYFAKEIP_REQUEST_EQUERYTYPE)


_CGAMESERVERS_GETSERVERLIST_REQUEST = _descriptor.Descriptor(
  name='CGameServers_GetServerList_Request',
  full_name='CGameServers_GetServerList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='CGameServers_GetServerList_Request.filter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Query filter string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='CGameServers_GetServerList_Request.limit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0307The maximum number of servers to return in the response', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=255,
)


_CGAMESERVERS_GETSERVERLIST_RESPONSE_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='CGameServers_GetServerList_Response.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='CGameServers_GetServerList_Response.Server.addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\036The server\'s IP and query port', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gameport', full_name='CGameServers_GetServerList_Response.Server.gameport', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='specport', full_name='CGameServers_GetServerList_Response.Server.specport', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameServers_GetServerList_Response.Server.steamid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CGameServers_GetServerList_Response.Server.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameServers_GetServerList_Response.Server.appid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gamedir', full_name='CGameServers_GetServerList_Response.Server.gamedir', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CGameServers_GetServerList_Response.Server.version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='CGameServers_GetServerList_Response.Server.product', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='CGameServers_GetServerList_Response.Server.region', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players', full_name='CGameServers_GetServerList_Response.Server.players', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_players', full_name='CGameServers_GetServerList_Response.Server.max_players', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bots', full_name='CGameServers_GetServerList_Response.Server.bots', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map', full_name='CGameServers_GetServerList_Response.Server.map', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secure', full_name='CGameServers_GetServerList_Response.Server.secure', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated', full_name='CGameServers_GetServerList_Response.Server.dedicated', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os', full_name='CGameServers_GetServerList_Response.Server.os', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gametype', full_name='CGameServers_GetServerList_Response.Server.gametype', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=738,
)

_CGAMESERVERS_GETSERVERLIST_RESPONSE = _descriptor.Descriptor(
  name='CGameServers_GetServerList_Response',
  full_name='CGameServers_GetServerList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='CGameServers_GetServerList_Response.servers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#List of servers matching the filter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CGAMESERVERS_GETSERVERLIST_RESPONSE_SERVER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=738,
)


_CGAMESERVERS_GETSERVERSTEAMIDSBYIP_REQUEST = _descriptor.Descriptor(
  name='CGameServers_GetServerSteamIDsByIP_Request',
  full_name='CGameServers_GetServerSteamIDsByIP_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_ips', full_name='CGameServers_GetServerSteamIDsByIP_Request.server_ips', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=740,
  serialized_end=804,
)


_CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='CGameServers_IPsWithSteamIDs_Response.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='CGameServers_IPsWithSteamIDs_Response.Server.addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameServers_IPsWithSteamIDs_Response.Server.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=951,
)

_CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE = _descriptor.Descriptor(
  name='CGameServers_IPsWithSteamIDs_Response',
  full_name='CGameServers_IPsWithSteamIDs_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='CGameServers_IPsWithSteamIDs_Response.servers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE_SERVER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=951,
)


_CGAMESERVERS_GETSERVERIPSBYSTEAMID_REQUEST = _descriptor.Descriptor(
  name='CGameServers_GetServerIPsBySteamID_Request',
  full_name='CGameServers_GetServerIPsBySteamID_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_steamids', full_name='CGameServers_GetServerIPsBySteamID_Request.server_steamids', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1022,
)


_CGAMESERVERS_QUERYBYFAKEIP_REQUEST = _descriptor.Descriptor(
  name='CGameServers_QueryByFakeIP_Request',
  full_name='CGameServers_QueryByFakeIP_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fake_ip', full_name='CGameServers_QueryByFakeIP_Request.fake_ip', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032FakeIP of server to query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fake_port', full_name='CGameServers_QueryByFakeIP_Request.fake_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035Fake port of server to query.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CGameServers_QueryByFakeIP_Request.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305AppID to use.  Each AppID has its own FakeIP address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_type', full_name='CGameServers_QueryByFakeIP_Request.query_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023What type of query?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CGAMESERVERS_QUERYBYFAKEIP_REQUEST_EQUERYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1432,
)


_CMSGGAMESERVERPINGQUERYDATA = _descriptor.Descriptor(
  name='CMsgGameServerPingQueryData',
  full_name='CMsgGameServerPingQueryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='CMsgGameServerPingQueryData.server_ip', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_port', full_name='CMsgGameServerPingQueryData.query_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgGameServerPingQueryData.game_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spectator_port', full_name='CMsgGameServerPingQueryData.spectator_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spectator_server_name', full_name='CMsgGameServerPingQueryData.spectator_server_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_name', full_name='CMsgGameServerPingQueryData.server_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgGameServerPingQueryData.steamid', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgGameServerPingQueryData.app_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gamedir', full_name='CMsgGameServerPingQueryData.gamedir', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map', full_name='CMsgGameServerPingQueryData.map', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_description', full_name='CMsgGameServerPingQueryData.game_description', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gametype', full_name='CMsgGameServerPingQueryData.gametype', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_players', full_name='CMsgGameServerPingQueryData.num_players', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_players', full_name='CMsgGameServerPingQueryData.max_players', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_bots', full_name='CMsgGameServerPingQueryData.num_bots', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgGameServerPingQueryData.password', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secure', full_name='CMsgGameServerPingQueryData.secure', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dedicated', full_name='CMsgGameServerPingQueryData.dedicated', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgGameServerPingQueryData.version', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdr_popid', full_name='CMsgGameServerPingQueryData.sdr_popid', index=19,
      number=20, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdr_location_string', full_name='CMsgGameServerPingQueryData.sdr_location_string', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1435,
  serialized_end=1899,
)


_CMSGGAMESERVERPLAYERSQUERYDATA_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgGameServerPlayersQueryData.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgGameServerPlayersQueryData.Player.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgGameServerPlayersQueryData.Player.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_played', full_name='CMsgGameServerPlayersQueryData.Player.time_played', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1993,
  serialized_end=2051,
)

_CMSGGAMESERVERPLAYERSQUERYDATA = _descriptor.Descriptor(
  name='CMsgGameServerPlayersQueryData',
  full_name='CMsgGameServerPlayersQueryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgGameServerPlayersQueryData.players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGAMESERVERPLAYERSQUERYDATA_PLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=2051,
)


_CMSGGAMESERVERRULESQUERYDATA_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='CMsgGameServerRulesQueryData.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='CMsgGameServerRulesQueryData.Rule.rule', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgGameServerRulesQueryData.Rule.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2136,
  serialized_end=2171,
)

_CMSGGAMESERVERRULESQUERYDATA = _descriptor.Descriptor(
  name='CMsgGameServerRulesQueryData',
  full_name='CMsgGameServerRulesQueryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='CMsgGameServerRulesQueryData.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGAMESERVERRULESQUERYDATA_RULE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2171,
)


_CGAMESERVERS_GAMESERVERQUERY_RESPONSE = _descriptor.Descriptor(
  name='CGameServers_GameServerQuery_Response',
  full_name='CGameServers_GameServerQuery_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='CGameServers_GameServerQuery_Response.ping_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players_data', full_name='CGameServers_GameServerQuery_Response.players_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules_data', full_name='CGameServers_GameServerQuery_Response.rules_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2368,
)


_GAMESERVERCLIENT_QUERYSERVERDATA_REQUEST = _descriptor.Descriptor(
  name='GameServerClient_QueryServerData_Request',
  full_name='GameServerClient_QueryServerData_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=2412,
)


_GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE = _descriptor.Descriptor(
  name='GameServerClient_QueryServerData_Response',
  full_name='GameServerClient_QueryServerData_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='GameServerClient_QueryServerData_Response.ping_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='players_data', full_name='GameServerClient_QueryServerData_Response.players_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules_data', full_name='GameServerClient_QueryServerData_Response.rules_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2415,
  serialized_end=2613,
)

_CGAMESERVERS_GETSERVERLIST_RESPONSE_SERVER.containing_type = _CGAMESERVERS_GETSERVERLIST_RESPONSE
_CGAMESERVERS_GETSERVERLIST_RESPONSE.fields_by_name['servers'].message_type = _CGAMESERVERS_GETSERVERLIST_RESPONSE_SERVER
_CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE_SERVER.containing_type = _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE
_CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE.fields_by_name['servers'].message_type = _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE_SERVER
_CGAMESERVERS_QUERYBYFAKEIP_REQUEST.fields_by_name['query_type'].enum_type = _CGAMESERVERS_QUERYBYFAKEIP_REQUEST_EQUERYTYPE
_CGAMESERVERS_QUERYBYFAKEIP_REQUEST_EQUERYTYPE.containing_type = _CGAMESERVERS_QUERYBYFAKEIP_REQUEST
_CMSGGAMESERVERPINGQUERYDATA.fields_by_name['server_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGGAMESERVERPLAYERSQUERYDATA_PLAYER.containing_type = _CMSGGAMESERVERPLAYERSQUERYDATA
_CMSGGAMESERVERPLAYERSQUERYDATA.fields_by_name['players'].message_type = _CMSGGAMESERVERPLAYERSQUERYDATA_PLAYER
_CMSGGAMESERVERRULESQUERYDATA_RULE.containing_type = _CMSGGAMESERVERRULESQUERYDATA
_CMSGGAMESERVERRULESQUERYDATA.fields_by_name['rules'].message_type = _CMSGGAMESERVERRULESQUERYDATA_RULE
_CGAMESERVERS_GAMESERVERQUERY_RESPONSE.fields_by_name['ping_data'].message_type = _CMSGGAMESERVERPINGQUERYDATA
_CGAMESERVERS_GAMESERVERQUERY_RESPONSE.fields_by_name['players_data'].message_type = _CMSGGAMESERVERPLAYERSQUERYDATA
_CGAMESERVERS_GAMESERVERQUERY_RESPONSE.fields_by_name['rules_data'].message_type = _CMSGGAMESERVERRULESQUERYDATA
_GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE.fields_by_name['ping_data'].message_type = _CMSGGAMESERVERPINGQUERYDATA
_GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE.fields_by_name['players_data'].message_type = _CMSGGAMESERVERPLAYERSQUERYDATA
_GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE.fields_by_name['rules_data'].message_type = _CMSGGAMESERVERRULESQUERYDATA
DESCRIPTOR.message_types_by_name['CGameServers_GetServerList_Request'] = _CGAMESERVERS_GETSERVERLIST_REQUEST
DESCRIPTOR.message_types_by_name['CGameServers_GetServerList_Response'] = _CGAMESERVERS_GETSERVERLIST_RESPONSE
DESCRIPTOR.message_types_by_name['CGameServers_GetServerSteamIDsByIP_Request'] = _CGAMESERVERS_GETSERVERSTEAMIDSBYIP_REQUEST
DESCRIPTOR.message_types_by_name['CGameServers_IPsWithSteamIDs_Response'] = _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE
DESCRIPTOR.message_types_by_name['CGameServers_GetServerIPsBySteamID_Request'] = _CGAMESERVERS_GETSERVERIPSBYSTEAMID_REQUEST
DESCRIPTOR.message_types_by_name['CGameServers_QueryByFakeIP_Request'] = _CGAMESERVERS_QUERYBYFAKEIP_REQUEST
DESCRIPTOR.message_types_by_name['CMsgGameServerPingQueryData'] = _CMSGGAMESERVERPINGQUERYDATA
DESCRIPTOR.message_types_by_name['CMsgGameServerPlayersQueryData'] = _CMSGGAMESERVERPLAYERSQUERYDATA
DESCRIPTOR.message_types_by_name['CMsgGameServerRulesQueryData'] = _CMSGGAMESERVERRULESQUERYDATA
DESCRIPTOR.message_types_by_name['CGameServers_GameServerQuery_Response'] = _CGAMESERVERS_GAMESERVERQUERY_RESPONSE
DESCRIPTOR.message_types_by_name['GameServerClient_QueryServerData_Request'] = _GAMESERVERCLIENT_QUERYSERVERDATA_REQUEST
DESCRIPTOR.message_types_by_name['GameServerClient_QueryServerData_Response'] = _GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CGameServers_GetServerList_Request = _reflection.GeneratedProtocolMessageType('CGameServers_GetServerList_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMESERVERS_GETSERVERLIST_REQUEST,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CGameServers_GetServerList_Request)
  })
_sym_db.RegisterMessage(CGameServers_GetServerList_Request)

CGameServers_GetServerList_Response = _reflection.GeneratedProtocolMessageType('CGameServers_GetServerList_Response', (_message.Message,), {

  'Server' : _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
    'DESCRIPTOR' : _CGAMESERVERS_GETSERVERLIST_RESPONSE_SERVER,
    '__module__' : 'steammessages_gameservers_pb2'
    # @@protoc_insertion_point(class_scope:CGameServers_GetServerList_Response.Server)
    })
  ,
  'DESCRIPTOR' : _CGAMESERVERS_GETSERVERLIST_RESPONSE,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CGameServers_GetServerList_Response)
  })
_sym_db.RegisterMessage(CGameServers_GetServerList_Response)
_sym_db.RegisterMessage(CGameServers_GetServerList_Response.Server)

CGameServers_GetServerSteamIDsByIP_Request = _reflection.GeneratedProtocolMessageType('CGameServers_GetServerSteamIDsByIP_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMESERVERS_GETSERVERSTEAMIDSBYIP_REQUEST,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CGameServers_GetServerSteamIDsByIP_Request)
  })
_sym_db.RegisterMessage(CGameServers_GetServerSteamIDsByIP_Request)

CGameServers_IPsWithSteamIDs_Response = _reflection.GeneratedProtocolMessageType('CGameServers_IPsWithSteamIDs_Response', (_message.Message,), {

  'Server' : _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
    'DESCRIPTOR' : _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE_SERVER,
    '__module__' : 'steammessages_gameservers_pb2'
    # @@protoc_insertion_point(class_scope:CGameServers_IPsWithSteamIDs_Response.Server)
    })
  ,
  'DESCRIPTOR' : _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CGameServers_IPsWithSteamIDs_Response)
  })
_sym_db.RegisterMessage(CGameServers_IPsWithSteamIDs_Response)
_sym_db.RegisterMessage(CGameServers_IPsWithSteamIDs_Response.Server)

CGameServers_GetServerIPsBySteamID_Request = _reflection.GeneratedProtocolMessageType('CGameServers_GetServerIPsBySteamID_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMESERVERS_GETSERVERIPSBYSTEAMID_REQUEST,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CGameServers_GetServerIPsBySteamID_Request)
  })
_sym_db.RegisterMessage(CGameServers_GetServerIPsBySteamID_Request)

CGameServers_QueryByFakeIP_Request = _reflection.GeneratedProtocolMessageType('CGameServers_QueryByFakeIP_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMESERVERS_QUERYBYFAKEIP_REQUEST,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CGameServers_QueryByFakeIP_Request)
  })
_sym_db.RegisterMessage(CGameServers_QueryByFakeIP_Request)

CMsgGameServerPingQueryData = _reflection.GeneratedProtocolMessageType('CMsgGameServerPingQueryData', (_message.Message,), {
  'DESCRIPTOR' : _CMSGGAMESERVERPINGQUERYDATA,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerPingQueryData)
  })
_sym_db.RegisterMessage(CMsgGameServerPingQueryData)

CMsgGameServerPlayersQueryData = _reflection.GeneratedProtocolMessageType('CMsgGameServerPlayersQueryData', (_message.Message,), {

  'Player' : _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), {
    'DESCRIPTOR' : _CMSGGAMESERVERPLAYERSQUERYDATA_PLAYER,
    '__module__' : 'steammessages_gameservers_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGameServerPlayersQueryData.Player)
    })
  ,
  'DESCRIPTOR' : _CMSGGAMESERVERPLAYERSQUERYDATA,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerPlayersQueryData)
  })
_sym_db.RegisterMessage(CMsgGameServerPlayersQueryData)
_sym_db.RegisterMessage(CMsgGameServerPlayersQueryData.Player)

CMsgGameServerRulesQueryData = _reflection.GeneratedProtocolMessageType('CMsgGameServerRulesQueryData', (_message.Message,), {

  'Rule' : _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
    'DESCRIPTOR' : _CMSGGAMESERVERRULESQUERYDATA_RULE,
    '__module__' : 'steammessages_gameservers_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGameServerRulesQueryData.Rule)
    })
  ,
  'DESCRIPTOR' : _CMSGGAMESERVERRULESQUERYDATA,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGameServerRulesQueryData)
  })
_sym_db.RegisterMessage(CMsgGameServerRulesQueryData)
_sym_db.RegisterMessage(CMsgGameServerRulesQueryData.Rule)

CGameServers_GameServerQuery_Response = _reflection.GeneratedProtocolMessageType('CGameServers_GameServerQuery_Response', (_message.Message,), {
  'DESCRIPTOR' : _CGAMESERVERS_GAMESERVERQUERY_RESPONSE,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:CGameServers_GameServerQuery_Response)
  })
_sym_db.RegisterMessage(CGameServers_GameServerQuery_Response)

GameServerClient_QueryServerData_Request = _reflection.GeneratedProtocolMessageType('GameServerClient_QueryServerData_Request', (_message.Message,), {
  'DESCRIPTOR' : _GAMESERVERCLIENT_QUERYSERVERDATA_REQUEST,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:GameServerClient_QueryServerData_Request)
  })
_sym_db.RegisterMessage(GameServerClient_QueryServerData_Request)

GameServerClient_QueryServerData_Response = _reflection.GeneratedProtocolMessageType('GameServerClient_QueryServerData_Response', (_message.Message,), {
  'DESCRIPTOR' : _GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE,
  '__module__' : 'steammessages_gameservers_pb2'
  # @@protoc_insertion_point(class_scope:GameServerClient_QueryServerData_Response)
  })
_sym_db.RegisterMessage(GameServerClient_QueryServerData_Response)


DESCRIPTOR._options = None
_CGAMESERVERS_GETSERVERLIST_REQUEST.fields_by_name['filter']._options = None
_CGAMESERVERS_GETSERVERLIST_REQUEST.fields_by_name['limit']._options = None
_CGAMESERVERS_GETSERVERLIST_RESPONSE_SERVER.fields_by_name['addr']._options = None
_CGAMESERVERS_GETSERVERLIST_RESPONSE.fields_by_name['servers']._options = None
_CGAMESERVERS_QUERYBYFAKEIP_REQUEST.fields_by_name['fake_ip']._options = None
_CGAMESERVERS_QUERYBYFAKEIP_REQUEST.fields_by_name['fake_port']._options = None
_CGAMESERVERS_QUERYBYFAKEIP_REQUEST.fields_by_name['app_id']._options = None
_CGAMESERVERS_QUERYBYFAKEIP_REQUEST.fields_by_name['query_type']._options = None

_GAMESERVERS = _descriptor.ServiceDescriptor(
  name='GameServers',
  full_name='GameServers',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\0302A service for searching and managing game servers.',
  create_key=_descriptor._internal_create_key,
  serialized_start=2616,
  serialized_end=3318,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetServerList',
    full_name='GameServers.GetServerList',
    index=0,
    containing_service=None,
    input_type=_CGAMESERVERS_GETSERVERLIST_REQUEST,
    output_type=_CGAMESERVERS_GETSERVERLIST_RESPONSE,
    serialized_options=b'\202\265\030,Gets a list of servers given a filter string',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServerSteamIDsByIP',
    full_name='GameServers.GetServerSteamIDsByIP',
    index=1,
    containing_service=None,
    input_type=_CGAMESERVERS_GETSERVERSTEAMIDSBYIP_REQUEST,
    output_type=_CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE,
    serialized_options=b'\202\265\0302Gets a list of server SteamIDs given a list of IPs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServerIPsBySteamID',
    full_name='GameServers.GetServerIPsBySteamID',
    index=2,
    containing_service=None,
    input_type=_CGAMESERVERS_GETSERVERIPSBYSTEAMID_REQUEST,
    output_type=_CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE,
    serialized_options=b'\202\265\030;Gets a list of server IP addresses given a list of SteamIDs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryByFakeIP',
    full_name='GameServers.QueryByFakeIP',
    index=3,
    containing_service=None,
    input_type=_CGAMESERVERS_QUERYBYFAKEIP_REQUEST,
    output_type=_CGAMESERVERS_GAMESERVERQUERY_RESPONSE,
    serialized_options=b'\202\265\030.Perform a query on a specific server by FakeIP',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GAMESERVERS)

DESCRIPTOR.services_by_name['GameServers'] = _GAMESERVERS


_GAMESERVERCLIENT = _descriptor.ServiceDescriptor(
  name='GameServerClient',
  full_name='GameServerClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\0303Service methods exposed by GameServer Steam clients\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=3321,
  serialized_end=3554,
  methods=[
  _descriptor.MethodDescriptor(
    name='QueryServerData',
    full_name='GameServerClient.QueryServerData',
    index=0,
    containing_service=None,
    input_type=_GAMESERVERCLIENT_QUERYSERVERDATA_REQUEST,
    output_type=_GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE,
    serialized_options=b'\202\265\030)Steam is asking a gameserver for its data',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GAMESERVERCLIENT)

DESCRIPTOR.services_by_name['GameServerClient'] = _GAMESERVERCLIENT

GameServers = service_reflection.GeneratedServiceType('GameServers', (_service.Service,), dict(
  DESCRIPTOR = _GAMESERVERS,
  __module__ = 'steammessages_gameservers_pb2'
  ))

GameServers_Stub = service_reflection.GeneratedServiceStubType('GameServers_Stub', (GameServers,), dict(
  DESCRIPTOR = _GAMESERVERS,
  __module__ = 'steammessages_gameservers_pb2'
  ))


GameServerClient = service_reflection.GeneratedServiceType('GameServerClient', (_service.Service,), dict(
  DESCRIPTOR = _GAMESERVERCLIENT,
  __module__ = 'steammessages_gameservers_pb2'
  ))

GameServerClient_Stub = service_reflection.GeneratedServiceStubType('GameServerClient_Stub', (GameServerClient,), dict(
  DESCRIPTOR = _GAMESERVERCLIENT,
  __module__ = 'steammessages_gameservers_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: test_messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='test_messages.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13test_messages.proto\"\xe9\x02\n\x13\x43omplexProtoMessage\x12\x10\n\x08number32\x18\x01 \x01(\r\x12\x10\n\x08number64\x18\x02 \x01(\x04\x12\x15\n\rlist_number32\x18\x03 \x03(\r\x12\x15\n\rlist_number64\x18\x04 \x03(\x04\x12\x33\n\x08messages\x18\x05 \x03(\x0b\x32!.ComplexProtoMessage.InnerMessage\x12\x31\n\x07\x62uffers\x18\x06 \x03(\x0b\x32 .ComplexProtoMessage.InnerBuffer\x1a-\n\x0cInnerMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07numbers\x18\x02 \x03(\r\x1ai\n\x0bInnerBuffer\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x35\n\x05\x66lags\x18\x02 \x03(\x0b\x32&.ComplexProtoMessage.InnerBuffer.Flags\x1a\x15\n\x05\x46lags\x12\x0c\n\x04\x66lag\x18\x01 \x01(\x08'
)




_COMPLEXPROTOMESSAGE_INNERMESSAGE = _descriptor.Descriptor(
  name='InnerMessage',
  full_name='ComplexProtoMessage.InnerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='ComplexProtoMessage.InnerMessage.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numbers', full_name='ComplexProtoMessage.InnerMessage.numbers', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=278,
)

_COMPLEXPROTOMESSAGE_INNERBUFFER_FLAGS = _descriptor.Descriptor(
  name='Flags',
  full_name='ComplexProtoMessage.InnerBuffer.Flags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag', full_name='ComplexProtoMessage.InnerBuffer.Flags.flag', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=385,
)

_COMPLEXPROTOMESSAGE_INNERBUFFER = _descriptor.Descriptor(
  name='InnerBuffer',
  full_name='ComplexProtoMessage.InnerBuffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ComplexProtoMessage.InnerBuffer.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='ComplexProtoMessage.InnerBuffer.flags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPLEXPROTOMESSAGE_INNERBUFFER_FLAGS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=385,
)

_COMPLEXPROTOMESSAGE = _descriptor.Descriptor(
  name='ComplexProtoMessage',
  full_name='ComplexProtoMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number32', full_name='ComplexProtoMessage.number32', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number64', full_name='ComplexProtoMessage.number64', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_number32', full_name='ComplexProtoMessage.list_number32', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_number64', full_name='ComplexProtoMessage.list_number64', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='ComplexProtoMessage.messages', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffers', full_name='ComplexProtoMessage.buffers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPLEXPROTOMESSAGE_INNERMESSAGE, _COMPLEXPROTOMESSAGE_INNERBUFFER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=385,
)

_COMPLEXPROTOMESSAGE_INNERMESSAGE.containing_type = _COMPLEXPROTOMESSAGE
_COMPLEXPROTOMESSAGE_INNERBUFFER_FLAGS.containing_type = _COMPLEXPROTOMESSAGE_INNERBUFFER
_COMPLEXPROTOMESSAGE_INNERBUFFER.fields_by_name['flags'].message_type = _COMPLEXPROTOMESSAGE_INNERBUFFER_FLAGS
_COMPLEXPROTOMESSAGE_INNERBUFFER.containing_type = _COMPLEXPROTOMESSAGE
_COMPLEXPROTOMESSAGE.fields_by_name['messages'].message_type = _COMPLEXPROTOMESSAGE_INNERMESSAGE
_COMPLEXPROTOMESSAGE.fields_by_name['buffers'].message_type = _COMPLEXPROTOMESSAGE_INNERBUFFER
DESCRIPTOR.message_types_by_name['ComplexProtoMessage'] = _COMPLEXPROTOMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComplexProtoMessage = _reflection.GeneratedProtocolMessageType('ComplexProtoMessage', (_message.Message,), {

  'InnerMessage' : _reflection.GeneratedProtocolMessageType('InnerMessage', (_message.Message,), {
    'DESCRIPTOR' : _COMPLEXPROTOMESSAGE_INNERMESSAGE,
    '__module__' : 'test_messages_pb2'
    # @@protoc_insertion_point(class_scope:ComplexProtoMessage.InnerMessage)
    })
  ,

  'InnerBuffer' : _reflection.GeneratedProtocolMessageType('InnerBuffer', (_message.Message,), {

    'Flags' : _reflection.GeneratedProtocolMessageType('Flags', (_message.Message,), {
      'DESCRIPTOR' : _COMPLEXPROTOMESSAGE_INNERBUFFER_FLAGS,
      '__module__' : 'test_messages_pb2'
      # @@protoc_insertion_point(class_scope:ComplexProtoMessage.InnerBuffer.Flags)
      })
    ,
    'DESCRIPTOR' : _COMPLEXPROTOMESSAGE_INNERBUFFER,
    '__module__' : 'test_messages_pb2'
    # @@protoc_insertion_point(class_scope:ComplexProtoMessage.InnerBuffer)
    })
  ,
  'DESCRIPTOR' : _COMPLEXPROTOMESSAGE,
  '__module__' : 'test_messages_pb2'
  # @@protoc_insertion_point(class_scope:ComplexProtoMessage)
  })
_sym_db.RegisterMessage(ComplexProtoMessage)
_sym_db.RegisterMessage(ComplexProtoMessage.InnerMessage)
_sym_db.RegisterMessage(ComplexProtoMessage.InnerBuffer)
_sym_db.RegisterMessage(ComplexProtoMessage.InnerBuffer.Flags)


# @@protoc_insertion_point(module_scope)



"""
Methods to call service methods, also known as unified messages

Example code:

.. code:: python

    # the easy way
    response = client.send_um_and_wait('Player.GetGameBadgeLevels#1', {
        'property': 1,
        'something': 'value',
        })

    print(response.body)

    # the other way
    jobid = client.send_um('Player.GetGameBadgeLevels#1', {'something': 1})
    response = client.wait_event(jobid)

The backend might error out, but we still get response. Here is how to check for error:

.. code:: python

    if response.header.eresult != EResult.OK:
        print(response.header.error_message)

"""
from steam.core.msg import MsgProto, get_um
from steam.enums.emsg import EMsg
from steam.utils.proto import proto_fill_from_dict


class UnifiedMessages(object):
    def __init__(self, *args, **kwargs):
        super(UnifiedMessages, self).__init__(*args, **kwargs)

    def send_um(self, method_name, params=None):
        """Send service method request

        :param method_name: method name (e.g. ``Player.GetGameBadgeLevels#1``)
        :type  method_name: :class:`str`
        :param params: message parameters
        :type  params: :class:`dict`
        :return: ``job_id`` identifier
        :rtype: :class:`str`

        Listen for ``jobid`` on this object to catch the response.
        """
        proto = get_um(method_name)

        if proto is None:
            raise ValueError("Failed to find method named: %s" % method_name)

        message = MsgProto(EMsg.ServiceMethodCallFromClient)
        message.header.target_job_name = method_name
        message.body = proto()

        if params:
            proto_fill_from_dict(message.body, params)

        return self.send_job(message)

    def send_um_and_wait(self, method_name, params=None, timeout=10, raises=False):
        """Send service method request and wait for response

        :param method_name: method name (e.g. ``Player.GetGameBadgeLevels#1``)
        :type  method_name: :class:`str`
        :param params: message parameters
        :type  params: :class:`dict`
        :param timeout: (optional) seconds to wait
        :type  timeout: :class:`int`
        :param raises: (optional) On timeout if :class:`False` return :class:`None`, else raise :class:`gevent.Timeout`
        :type  raises: :class:`bool`
        :return: response message
        :rtype: proto message instance
        :raises: :class:`gevent.Timeout`
        """
        job_id = self.send_um(method_name, params)
        return self.wait_msg(job_id, timeout, raises=raises)



#!/usr/bin/env python

from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()\
                        .replace('.io/en/latest/', '.io/en/stable/')\
                        .replace('?badge=latest', '?badge=stable')\
                        .replace('projects/steam/badge/?version=latest', 'projects/steam/badge/?version=stable')
with open(path.join(here, 'steam/__init__.py'), encoding='utf-8') as f:
    __version__ = f.readline().split('"')[1]

install_requires = [
    'six>=1.10',
    'pycryptodomex>=3.7.0',
    'requests>=2.9.1',
    'vdf>=3.3',
    'cachetools>=3.0.0',
    "win-inet-pton; python_version == '2.7' and sys_platform == 'win32'",
    "enum34==1.1.2; python_version < '3.4'",
]

install_extras = {
    'client': [
        'gevent>=1.3.0',
        'protobuf~=3.0; python_version >= "3"',
        'protobuf<3.18.0; python_version < "3"',
        'gevent-eventemitter~=2.1',
    ],
}

setup(
    name='steam',
    version=__version__,
    description='Module for interacting with various Steam features',
    long_description=long_description,
    url='https://github.com/ValvePython/steam',
    author="Rossen Georgiev",
    author_email='rossen@rgp.io',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Natural Language :: English',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
    keywords='valve steam steamid api webapi steamcommunity',
    packages=['steam'] + ['steam.'+x for x in find_packages(where='steam')],
    install_requires=install_requires,
    extras_require=install_extras,
    zip_safe=True,
)
